Skip to contents

G2 has 73 categories. This function returns the default partition used by [prepare_caf_data()]. Override by passing a list with the same structure.

Usage

caf2021_g2_groups()

Value

A named list of integer vectors.